==> v0.7.10.zip: antares/src/renderer/i18n/de-DE.ts <==
export const deDE = {
   word: {
      edit: 'Bearbeiten',
      save: 'Speichern',
      close: 'Schließen',
      delete: 'Löschen',
      confirm: 'Bestätigen',
      cancel: 'Abbrechen',
      send: 'Senden',
      connectionName: 'Verbindungsname',
      client: 'Client',
      hostName: 'Hostname',
      port: 'Port',
      user: 'Nutzer',
      password: 'Kennwort',
      credentials: 'Zugangsdaten',
      connect: 'Verbinden',
      connected: 'Verbunden',
      disconnect: 'Trennen',
      disconnected: 'Getrennt',
      refresh: 'Aktualisieren',
      settings: 'Einstellungen',
      general: 'Allgemein',
      themes: 'Designs',
      update: 'Aktualisierung',
      about: 'Über',
      language: 'Sprache',
      version: 'Version',
      donate: 'Spenden',
      run: 'Ausführen',
      schema: 'Schema',
      results: 'Ergebnisse',
      size: 'Größe',
      seconds: 'Sekunden',
      type: 'Typ',
      mimeType: 'Mime-Type',
      download: 'Herunterladen',
      add: 'Hinzufügen',
      data: 'Daten',
      properties: 'Eigenschaften',
      insert: 'Einfügen',
      connecting: 'Verbinden',
      name: 'Name',
      collation: 'Kollation',
      clear: 'Leeren',
      options: 'Optionen',
      autoRefresh: 'Auto-Aktualisierung',
      indexes: 'Indizes',
      foreignKeys: 'Fremdschlüssel',
      length: 'Länge',
      unsigned: 'Unsigniert',
      default: 'Standard',
      comment: 'Kommentar',
      key: 'Schlüssel',
      order: 'Sortierung',
      expression: 'Ausdruck',
      autoIncrement: 'Auto Inkrement',
      engine: 'Engine',
      field: 'Feld | Felder',
      approximately: 'Ungefähr',
      total: 'Gesamt',
      table: 'Tabelle',
      discard: 'Verwerfen',
      stay: 'Warten',
      author: 'Autor',
      light: 'Hell',
      dark: 'Dunkel',
      autoCompletion: 'Auto-Vervollständigung',
      application: 'Anwendung',
      editor: 'Editor',
      view: 'Ansicht',
      definer: 'Bestimmer',
      algorithm: 'Algorithmus',
      trigger: 'Auslöser',
      storedRoutine: 'Gespeicherte Routine | Gespeicherte Routinen',
      scheduler: 'Zeitplaner',
      event: 'Ereignis',
      parameters: 'Parameter',
      function: 'Funktion | Funktionen',
      deterministic: 'Deterministisch',
      context: 'Kontext',
      export: 'Export',
      returns: 'Rückgabe',
      timing: 'Dauer',
      state: 'Stand',
      execution: 'Ausführung',
      starts: 'Startet',
      ends: 'Endet',
      ssl: 'SSL',
      privateKey: 'Privater Schlüssel',
      certificate: 'Zertifikat',
      caCertificate: 'CA Zertifikat',
      ciphers: 'Chiffren',
      upload: 'Hochladen',
      browse: 'Suchen',
      faker: 'Faker',
      content: 'Inhalt',
      cut: 'Ausschneiden',
      copy: 'Kopieren',
      paste: 'Einfügen',
      tools: 'Tools',
      variables: 'Variablen',
      processes: 'Prozesse',
      database: 'Datenbank',
      scratchpad: 'Scratchpad',
      array: 'Array',
      format: 'Formatierung',
      sshTunnel: 'SSH Tunnel'
   },
   message: {
      appWelcome: 'Willkommen im Antares SQL Client!',
      appFirstStep: 'Dein erster Schritt: Erstelle eine neue Datenbankverbindung.',
      addConnection: 'Verbindung hinzufügen',
      createConnection: 'Verbindung erstellen',
      createNewConnection: 'Neue Verbindung erstellen',
      askCredentials: 'Frage nach Zugangsdaten',
      testConnection: 'Verbindung testen',
      editConnection: 'Verbindung bearbeiten',
      deleteConnection: 'Verbindung löschen',
      deleteCorfirm: 'Bestätige den Abbruch von',
      connectionSuccessfullyMade: 'Verbindung erfolgreich erstellt!',
      madeWithJS: 'Mit 💛 und JavaScript gemacht!',
      checkForUpdates: 'Suche nach Aktualisierungen',
      noUpdatesAvailable: 'Keine Aktualisierungen verfügbar',
      checkingForUpdate: 'Suche nach Aktualisierungen',
      checkFailure: 'Suche fehlgeschlagen, bitte versuche es später noch einmal',
      updateAvailable: 'Aktualisierung verfügbar',
      downloadingUpdate: 'Aktualisierung wird heruntergeladen',
      updateDownloaded: 'Aktualisierung heruntergeladen',
      restartToInstall: 'Starte Antares neu für die Installation',
      unableEditFieldWithoutPrimary: 'Feld kann ohne Primärschlüssel in Ergebnisliste nicht bearbeitet werden',
      editCell: 'Zelle bearbeiten',
      deleteRows: 'Zeile löschen | Lösche {count} Zeilen',
      confirmToDeleteRows: 'Eine Zeile wirklich löschen? | {count} Zeilen wirklich löschen?',
      notificationsTimeout: 'Timeout für Benachrichtigungen',
      uploadFile: 'Datei hochladen',
      addNewRow: 'Neue Zeile hinzufügen',
      numberOfInserts: 'Anzahl der eingefügten Zeilen',
      openNewTab: 'Öffne einen neuen Tab',
      affectedRows: 'Betroffene Zeilen',
      createNewDatabase: 'Erstelle ein neue Datenbank',
      databaseName: 'Datenbankname',
      serverDefault: 'Server default',
      deleteDatabase: 'Datenbank löschen',
      editDatabase: 'Datenbank bearbeiten',
      clearChanges: 'Änderungen leeren',
      addNewField: 'Neues Feld hinzufügen',
      manageIndexes: 'Indizes verwalten',
      manageForeignKeys: 'Fremdschlüssel verwalten',
      allowNull: 'Erlaube NULL',
      zeroFill: 'Nullauffüllung',
      customValue: 'Spezifischer Wert',
      onUpdate: 'Bei Aktualisierung',
      deleteField: 'Feld löschen',
      createNewIndex: 'Neuen Index erstellen',
      addToIndex: 'Zum Index hinzufügen',
      createNewTable: 'Neue Tabelle erstellen',
      emptyTable: 'Tabelle leeren',
      deleteTable: 'Tabelle löschen',
      emptyCorfirm: 'Wirklich leeren?',
      unsavedChanges: 'Ungespeicherte Änderungen',
      discardUnsavedChanges: 'Du hast ungespeicherte Änderungen. Wenn du den Tab verlässt, werden diese Änderungen verworfen.',
      thereAreNoIndexes: 'Es gibt keine Indizes',
      thereAreNoForeign: 'Es gibt keine Fremdschlüssel',
      createNewForeign: 'Neuen Fremdschlüssel erstellen',
      referenceTable: 'Referenztabelle',
      referenceField: 'Referenzfeld',
      foreignFields: 'Fremdfelder',
      invalidDefault: 'Ungültiger Standard',
      onDelete: 'Bei Löschung',
      applicationTheme: 'Anwendungsdesign',
      editorTheme: 'Editordesign',
      wrapLongLines: 'Lange Zeilen umbrechen',
      selectStatement: 'Select-Anweisung',
      triggerStatement: 'Trigger-Anweisung',
      sqlSecurity: 'SQL-Sicherheit',
      updateOption: 'Aktualisierungsoption',
      deleteView: 'View löschen',
      createNewView: 'Neue View erstellen',
      deleteTrigger: 'Trigger löschen',
      createNewTrigger: 'Neuen Trigger erstellen',
      currentUser: 'Aktueller Nutzer',
      routineBody: 'Routineninhalt',
      dataAccess: 'Datenzugriff',
      thereAreNoParameters: 'Es gibt keine Parameter',
      createNewParameter: 'Neue Parameter erstellen',
      createNewRoutine: 'Neue Routine erstellen',
      deleteRoutine: 'Routine löschen',
      functionBody: 'Funktionsinhalt',
      createNewFunction: 'Neue Funktion erstellen',
      deleteFunction: 'Funktion löschen',
      schedulerBody: 'Zeitplaner-Inhalt',
      createNewScheduler: 'Neuen Zeitplaner erstellen',
      deleteScheduler: 'Zeitplaner löschen',
      preserveOnCompletion: 'Bei Vervollständigung erhalten',
      enableSsl: 'Aktiviere SSL',
      manualValue: 'Manueller Wert',
      tableFiller: 'Tabellenfüller',
      fakeDataLanguage: 'Fingierte Datensprache',
      searchForElements: 'Suche nach Elemente',
      selectAll: 'Alle auswählen',
      queryDuration: 'Dauer der Abfrage',
      includeBetaUpdates: 'Beta-Aktualisierungen berücksichtigen',
      setNull: 'Setze NULL',
      processesList: 'Prozessliste',
      processInfo: 'Prozessinformationen',
      manageUsers: 'Benutzer verwalten',
      createNewSchema: 'Neues Schema erstellen',
      schemaName: 'Schemaname',
      editSchema: 'Schema bearbeiten',
      deleteSchema: 'Schema löschen',
      markdownSupported: 'Unterstützt Markdown',
      plantATree: 'Pflanze einen Baum',
      dataTabPageSize: 'Einträge pro Tab / Seite',
      enableSsh: 'Aktiviere SSH'
   },
   faker: {
      address: 'Adresse',
      commerce: 'Handel',
      company: 'Firma',
      database: 'Datenbank',
      date: 'Datum',
      finance: 'Finanzen',
      git: 'Git',
      hacker: 'Hacker',
      internet: 'Internet',
      lorem: 'Lorem',
      name: 'Name',
      music: 'Musik',
      phone: 'Telefon',
      random: 'Zufällig',
      system: 'System',
      time: 'Zeit',
      vehicle: 'Fahrzeug',
      zipCode: 'Postleitzahl',
      zipCodeByState: 'Postleitzahl nach Stadt',
      city: 'Stadt',
      cityPrefix: 'Stadtpräfix',
      citySuffix: 'Stadtzusatz',
      streetName: 'Straßenname',
      streetAddress: 'Anschrift',
      streetSuffix: 'Straßenzusatz',
      streetPrefix: 'Straßenpräfix',
      secondaryAddress: 'Zweite Anschrift',
      county: 'Landkreis',
      country: 'Land',
      countryCode: 'Ländercode',
      state: 'Bundesland',
      stateAbbr: 'Bundeslandkürzel',
      latitude: 'Breitengrad',
      longitude: 'Längengrad',
      direction: 'Richtung',
      cardinalDirection: 'Himmelsrichtung',
      ordinalDirection: 'Nebenhimmelsrichtung',
      nearbyGPSCoordinate: 'Nächste GPS-Koordinate',
      timeZone: 'Zeitzone',
      color: 'Farbe',
      department: 'Abteilung',
      productName: 'Produktname',
      price: 'Preis',
      productAdjective: 'Produkteigenschaft',
      productMaterial: 'Produktmaterial',
      product: 'Produkt',
      productDescription: 'Produktbeschreibung',
      suffixes: 'Zusätze',
      companyName: 'Firmenname',
      companySuffix: 'Firmenzusatz',
      catchPhrase: 'Slogan',
      bs: 'BS',
      catchPhraseAdjective: 'Sloganeigenschaft',
      catchPhraseDescriptor: 'Sloganbeschreibung',
      catchPhraseNoun: 'Slogannomen',
      bsAdjective: 'BS-Eigenschaft',
      bsBuzz: 'BS-Klatsch',
      bsNoun: 'BS-Nomen',
      column: 'Spalte',
      type: 'Typ',
      collation: 'Kollation',
      engine: 'Engine',
      past: 'Vergangenheit',
      future: 'Zukunft',
      between: 'Zwischen',
      recent: 'Kürzlich',
      soon: 'Bald',
      month: 'Monat',
      weekday: 'Wochentag',
      account: 'Konto',
      accountName: 'Kontoname',
      routingNumber: 'Bankleitzahl',
      mask: 'Maske',
      amount: 'Wert',
      transactionType: 'Vorgangstyp',
      currencyCode: 'Währungscode',
      currencyName: 'Währungsname',
      currencySymbol: 'Währungssymbol',
      bitcoinAddress: 'Bitcoin-Adresse',
      litecoinAddress: 'Litecoin-Adresse',
      creditCardNumber: 'Kreditkartennummer',
      creditCardCVV: 'Kartenprüfnummer',
      ethereumAddress: 'Ethereum-Adresse',
      iban: 'IBAN',
      bic: 'BIC',
      transactionDescription: 'Vorgangsbeschreibung',
      branch: 'Zweig',
      commitEntry: 'Commit-Eintrag',
      commitMessage: 'Commit-Nachricht',
      commitSha: 'Commit-SHA',
      shortSha: 'Kurzer SHA',
      abbreviation: 'Kürzel',
      adjective: 'Adjektiv',
      noun: 'Nomen',
      verb: 'Verb',
      ingverb: 'Ingverb',
      phrase: 'Phrase',
      avatar: 'Avatar',
      email: 'E-Mail',
      exampleEmail: 'Beispiel-E-Mail',
      userName: 'Benutzername',
      protocol: 'Protokoll',
      url: 'Url',
      domainName: 'Domainname',
      domainSuffix: 'Domainzusatz',
      domainWord: 'Domainwort',
      ip: 'IP',
      ipv6: 'IPv6',
      userAgent: 'Browserkennung',
      mac: 'Mac',
      password: 'Kennwort',
      word: 'Wort',
      words: 'Wörter',
      sentence: 'Satz',
      slug: 'Slug',
      sentences: 'Sätze',
      paragraph: 'Paragraph',
      paragraphs: 'Paragraphen',
      text: 'Text',
      lines: 'Zeilen',
      genre: 'Genre',
      firstName: 'Vorname',
      lastName: 'Nachname',
      middleName: 'Zweitname',
      findName: 'Vollständiger Name',
      jobTitle: 'Berufsbezeichnung',
      gender: 'Geschlecht',
      prefix: 'Präfix',
      suffix: 'Zusatz',
      title: 'Titel',
      jobDescriptor: 'Berufsbeschreibung',
      jobArea: 'Berufsfeld',
      jobType: 'Anstellungsart',
      phoneNumber: 'Telefonnummer',
      phoneNumberFormat: 'Telefonnummerformat',
      phoneFormats: 'Telefonnummerformate',
      number: 'Nummer',
      float: 'Gleitkommazahl',
      arrayElement: 'Array-Element',
      arrayElements: 'Array-Elemente',
      objectElement: 'Object-Element',
      uuid: 'Uuid',
      boolean: 'Boolean',
      image: 'Grafik',
      locale: 'Sprachumgebung',
      alpha: 'Alpha',
      alphaNumeric: 'Alphanumerisch',
      hexaDecimal: 'Hexadezimal',
      fileName: 'Dateiname',
      commonFileName: 'Allgemeiner Dateiname',
      mimeType: 'Mimetype',
      commonFileType: 'Allgemeiner Dateityp',
      commonFileExt: 'Allgemeine Dateiendung',
      fileType: 'Dateityp',
      fileExt: 'Dateiendung',
      directoryPath: 'Verzeichnispfad',
      filePath: 'Dateipfad',
      semver: 'Semver',
      manufacturer: 'Hersteller',
      model: 'Modell',
      fuel: 'Treibstoff',
      vin: 'Wein'
   }
};

==> v0.7.21.zip: antares/src/renderer/i18n/de-DE.ts <==
export const deDE = {
   general: {
      edit: 'Bearbeiten',
      save: 'Speichern',
      close: 'Schließen',
      delete: 'Löschen',
      confirm: 'Bestätigen',
      cancel: 'Abbrechen',
      send: 'Senden',
      refresh: 'Aktualisieren',
      autoRefresh: 'Auto-Aktualisierung',
      version: 'Version',
      donate: 'Spenden',
      run: 'Ausführen',
      results: 'Ergebnisse',
      size: 'Größe',
      mimeType: 'Mime-Type',
      download: 'Herunterladen',
      add: 'Hinzufügen',
      data: 'Daten',
      properties: 'Eigenschaften',
      insert: 'Einfügen',
      name: 'Name',
      clear: 'Leeren',
      seconds: 'Sekunden',
      options: 'Optionen',
      discard: 'Verwerfen',
      stay: 'Warten',
      author: 'Autor',
      upload: 'Hochladen',
      browse: 'Suchen',
      content: 'Inhalt',
      cut: 'Ausschneiden',
      copy: 'Kopieren',
      paste: 'Einfügen',
      tools: 'Tools',
      format: 'Formatierung',
      deleteConfirm: 'Bestätige den Abbruch von',
      uploadFile: 'Datei hochladen',
      manualValue: 'Manueller Wert',
      selectAll: 'Alle auswählen'
   },
   connection: {
      connectionName: 'Verbindungsname',
      client: 'Client',
      hostName: 'Hostname',
      port: 'Port',
      user: 'Nutzer',
      password: 'Kennwort',
      credentials: 'Zugangsdaten',
      connect: 'Verbinden',
      connected: 'Verbunden',
      disconnect: 'Trennen',
      disconnected: 'Getrennt',
      ssl: 'SSL',
      privateKey: 'Privater Schlüssel',
      certificate: 'Zertifikat',
      caCertificate: 'CA Zertifikat',
      ciphers: 'Chiffren',
      sshTunnel: 'SSH Tunnel',
      addConnection: 'Verbindung hinzufügen',
      createConnection: 'Verbindung erstellen',
      createNewConnection: 'Neue Verbindung erstellen',
      askCredentials: 'Frage nach Zugangsdaten',
      testConnection: 'Verbindung testen',
      editConnection: 'Verbindung bearbeiten',
      deleteConnection: 'Verbindung löschen',
      connectionSuccessfullyMade: 'Verbindung erfolgreich erstellt!',
      enableSsl: 'Aktiviere SSL',
      enableSsh: 'Aktiviere SSH',
      keepAliveInterval: 'Keep-Alive-Intervall'
   },
   database: {
      schema: 'Schema',
      type: 'Typ',
      foreignKeys: 'Fremdschlüssel',
      length: 'Länge',
      unsigned: 'Unsigniert',
      default: 'Standard',
      comment: 'Kommentar',
      collation: 'Kollation',
      key: 'Schlüssel',
      order: 'Sortierung',
      expression: 'Ausdruck',
      autoIncrement: 'Auto Inkrement',
      engine: 'Engine',
      field: 'Feld | Felder',
      approximately: 'Ungefähr',
      total: 'Gesamt',
      table: 'Tabelle',
      view: 'Ansicht',
      indexes: 'Indizes',
      definer: 'Bestimmer',
      algorithm: 'Algorithmus',
      trigger: 'Auslöser',
      storedRoutine: 'Gespeicherte Routine | Gespeicherte Routinen',
      scheduler: 'Zeitplaner',
      event: 'Ereignis',
      parameters: 'Parameter',
      function: 'Funktion | Funktionen',
      deterministic: 'Deterministisch',
      context: 'Kontext',
      export: 'Export',
      returns: 'Rückgabe',
      timing: 'Dauer',
      state: 'Stand',
      execution: 'Ausführung',
      starts: 'Startet',
      ends: 'Endet',
      variables: 'Variablen',
      processes: 'Prozesse',
      database: 'Datenbank',
      array: 'Array',
      unableEditFieldWithoutPrimary: 'Feld kann ohne Primärschlüssel in Ergebnisliste nicht bearbeitet werden',
      editCell: 'Zelle bearbeiten',
      deleteRows: 'Zeile löschen | Lösche {count} Zeilen',
      confirmToDeleteRows: 'Eine Zeile wirklich löschen? | {count} Zeilen wirklich löschen?',
      addNewRow: 'Neue Zeile hinzufügen',
      numberOfInserts: 'Anzahl der eingefügten Zeilen',
      affectedRows: 'Betroffene Zeilen',
      createNewDatabase: 'Erstelle ein neue Datenbank',
      databaseName: 'Datenbankname',
      serverDefault: 'Server default',
      deleteDatabase: 'Datenbank löschen',
      editDatabase: 'Datenbank bearbeiten',
      clearChanges: 'Änderungen leeren',
      addNewField: 'Neues Feld hinzufügen',
      manageIndexes: 'Indizes verwalten',
      manageForeignKeys: 'Fremdschlüssel verwalten',
      allowNull: 'Erlaube NULL',
      zeroFill: 'Nullauffüllung',
      customValue: 'Spezifischer Wert',
      onUpdate: 'Bei Aktualisierung',
      deleteField: 'Feld löschen',
      createNewIndex: 'Neuen Index erstellen',
      addToIndex: 'Zum Index hinzufügen',
      createNewTable: 'Neue Tabelle erstellen',
      emptyTable: 'Tabelle leeren',
      deleteTable: 'Tabelle löschen',
      emptyConfirm: 'Wirklich leeren?',
      thereAreNoIndexes: 'Es gibt keine Indizes',
      thereAreNoForeign: 'Es gibt keine Fremdschlüssel',
      createNewForeign: 'Neuen Fremdschlüssel erstellen',
      referenceTable: 'Referenztabelle',
      referenceField: 'Referenzfeld',
      foreignFields: 'Fremdfelder',
      invalidDefault: 'Ungültiger Standard',
      onDelete: 'Bei Löschung',
      selectStatement: 'Select-Anweisung',
      triggerStatement: 'Trigger-Anweisung',
      sqlSecurity: 'SQL-Sicherheit',
      updateOption: 'Aktualisierungsoption',
      deleteView: 'View löschen',
      createNewView: 'Neue View erstellen',
      deleteTrigger: 'Trigger löschen',
      createNewTrigger: 'Neuen Trigger erstellen',
      currentUser: 'Aktueller Nutzer',
      routineBody: 'Routineninhalt',
      dataAccess: 'Datenzugriff',
      thereAreNoParameters: 'Es gibt keine Parameter',
      createNewParameter: 'Neue Parameter erstellen',
      createNewRoutine: 'Neue Routine erstellen',
      deleteRoutine: 'Routine löschen',
      functionBody: 'Funktionsinhalt',
      createNewFunction: 'Neue Funktion erstellen',
      deleteFunction: 'Funktion löschen',
      schedulerBody: 'Zeitplaner-Inhalt',
      createNewScheduler: 'Neuen Zeitplaner erstellen',
      deleteScheduler: 'Zeitplaner löschen',
      preserveOnCompletion: 'Bei Vervollständigung erhalten',
      tableFiller: 'Tabellenfüller',
      fakeDataLanguage: 'Fingierte Datensprache',
      queryDuration: 'Dauer der Abfrage',
      setNull: 'Setze NULL',
      processesList: 'Prozessliste',
      processInfo: 'Prozessinformationen',
      manageUsers: 'Benutzer verwalten',
      createNewSchema: 'Neues Schema erstellen',
      schemaName: 'Schemaname',
      editSchema: 'Schema bearbeiten',
      deleteSchema: 'Schema löschen'
   },
   application: {
      settings: 'Einstellungen',
      general: 'Allgemein',
      themes: 'Designs',
      update: 'Aktualisierung',
      about: 'Über',
      language: 'Sprache',
      light: 'Hell',
      dark: 'Dunkel',
      autoCompletion: 'Auto-Vervollständigung',
      application: 'Anwendung',
      editor: 'Editor',
      scratchpad: 'Scratchpad',
      madeWithJS: 'Mit 💛 und JavaScript gemacht!',
      checkForUpdates: 'Suche nach Aktualisierungen',
      noUpdatesAvailable: 'Keine Aktualisierungen verfügbar',
      checkingForUpdate: 'Suche nach Aktualisierungen',
      checkFailure: 'Suche fehlgeschlagen, bitte versuche es später noch einmal',
      updateAvailable: 'Aktualisierung verfügbar',
      downloadingUpdate: 'Aktualisierung wird heruntergeladen',
      updateDownloaded: 'Aktualisierung heruntergeladen',
      restartToInstall: 'Starte Antares neu für die Installation',
      notificationsTimeout: 'Timeout für Benachrichtigungen',
      openNewTab: 'Öffne einen neuen Tab',
      unsavedChanges: 'Ungespeicherte Änderungen',
      discardUnsavedChanges: 'Du hast ungespeicherte Änderungen. Wenn du den Tab verlässt, werden diese Änderungen verworfen.',
      applicationTheme: 'Anwendungsdesign',
      editorTheme: 'Editordesign',
      wrapLongLines: 'Lange Zeilen umbrechen',
      includeBetaUpdates: 'Beta-Aktualisierungen berücksichtigen',
      markdownSupported: 'Unterstützt Markdown',
      plantATree: 'Pflanze einen Baum',
      dataTabPageSize: 'Einträge pro Tab / Seite',
      searchForElements: 'Suche nach Elemente'
   },
   faker: {
      address: 'Adresse',
      commerce: 'Handel',
      company: 'Firma',
      database: 'Datenbank',
      date: 'Datum',
      finance: 'Finanzen',
      git: 'Git',
      hacker: 'Hacker',
      internet: 'Internet',
      lorem: 'Lorem',
      name: 'Name',
      music: 'Musik',
      phone: 'Telefon',
      random: 'Zufällig',
      system: 'System',
      time: 'Zeit',
      vehicle: 'Fahrzeug',
      zipCode: 'Postleitzahl',
      zipCodeByState: 'Postleitzahl nach Stadt',
      city: 'Stadt',
      cityPrefix: 'Stadtpräfix',
      citySuffix: 'Stadtzusatz',
      streetName: 'Straßenname',
      streetAddress: 'Anschrift',
      streetSuffix: 'Straßenzusatz',
      streetPrefix: 'Straßenpräfix',
      secondaryAddress: 'Zweite Anschrift',
      county: 'Landkreis',
      country: 'Land',
      countryCode: 'Ländercode',
      state: 'Bundesland',
      stateAbbr: 'Bundeslandkürzel',
      latitude: 'Breitengrad',
      longitude: 'Längengrad',
      direction: 'Richtung',
      cardinalDirection: 'Himmelsrichtung',
      ordinalDirection: 'Nebenhimmelsrichtung',
      nearbyGPSCoordinate: 'Nächste GPS-Koordinate',
      timeZone: 'Zeitzone',
      color: 'Farbe',
      department: 'Abteilung',
      productName: 'Produktname',
      price: 'Preis',
      productAdjective: 'Produkteigenschaft',
      productMaterial: 'Produktmaterial',
      product: 'Produkt',
      productDescription: 'Produktbeschreibung',
      suffixes: 'Zusätze',
      companyName: 'Firmenname',
      companySuffix: 'Firmenzusatz',
      catchPhrase: 'Slogan',
      bs: 'BS',
      catchPhraseAdjective: 'Sloganeigenschaft',
      catchPhraseDescriptor: 'Sloganbeschreibung',
      catchPhraseNoun: 'Slogannomen',
      bsAdjective: 'BS-Eigenschaft',
      bsBuzz: 'BS-Klatsch',
      bsNoun: 'BS-Nomen',
      column: 'Spalte',
      type: 'Typ',
      collation: 'Kollation',
      engine: 'Engine',
      past: 'Vergangenheit',
      future: 'Zukunft',
      between: 'Zwischen',
      recent: 'Kürzlich',
      soon: 'Bald',
      month: 'Monat',
      weekday: 'Wochentag',
      account: 'Konto',
      accountName: 'Kontoname',
      routingNumber: 'Bankleitzahl',
      mask: 'Maske',
      amount: 'Wert',
      transactionType: 'Vorgangstyp',
      currencyCode: 'Währungscode',
      currencyName: 'Währungsname',
      currencySymbol: 'Währungssymbol',
      bitcoinAddress: 'Bitcoin-Adresse',
      litecoinAddress: 'Litecoin-Adresse',
      creditCardNumber: 'Kreditkartennummer',
      creditCardCVV: 'Kartenprüfnummer',
      ethereumAddress: 'Ethereum-Adresse',
      iban: 'IBAN',
      bic: 'BIC',
      transactionDescription: 'Vorgangsbeschreibung',
      branch: 'Zweig',
      commitEntry: 'Commit-Eintrag',
      commitMessage: 'Commit-Nachricht',
      commitSha: 'Commit-SHA',
      shortSha: 'Kurzer SHA',
      abbreviation: 'Kürzel',
      adjective: 'Adjektiv',
      noun: 'Nomen',
      verb: 'Verb',
      ingverb: 'Ingverb',
      phrase: 'Phrase',
      avatar: 'Avatar',
      email: 'E-Mail',
      exampleEmail: 'Beispiel-E-Mail',
      userName: 'Benutzername',
      protocol: 'Protokoll',
      url: 'Url',
      domainName: 'Domainname',
      domainSuffix: 'Domainzusatz',
      domainWord: 'Domainwort',
      ip: 'IP',
      ipv6: 'IPv6',
      userAgent: 'Browserkennung',
      mac: 'Mac',
      password: 'Kennwort',
      word: 'Wort',
      words: 'Wörter',
      sentence: 'Satz',
      slug: 'Slug',
      sentences: 'Sätze',
      paragraph: 'Paragraph',
      paragraphs: 'Paragraphen',
      text: 'Text',
      lines: 'Zeilen',
      genre: 'Genre',
      firstName: 'Vorname',
      lastName: 'Nachname',
      middleName: 'Zweitname',
      findName: 'Vollständiger Name',
      jobTitle: 'Berufsbezeichnung',
      gender: 'Geschlecht',
      prefix: 'Präfix',
      suffix: 'Zusatz',
      title: 'Titel',
      jobDescriptor: 'Berufsbeschreibung',
      jobArea: 'Berufsfeld',
      jobType: 'Anstellungsart',
      phoneNumber: 'Telefonnummer',
      phoneNumberFormat: 'Telefonnummerformat',
      phoneFormats: 'Telefonnummerformate',
      number: 'Nummer',
      float: 'Gleitkommazahl',
      arrayElement: 'Array-Element',
      arrayElements: 'Array-Elemente',
      objectElement: 'Object-Element',
      uuid: 'Uuid',
      boolean: 'Boolean',
      image: 'Grafik',
      locale: 'Sprachumgebung',
      alpha: 'Alpha',
      alphaNumeric: 'Alphanumerisch',
      hexaDecimal: 'Hexadezimal',
      fileName: 'Dateiname',
      commonFileName: 'Allgemeiner Dateiname',
      mimeType: 'Mimetype',
      commonFileType: 'Allgemeiner Dateityp',
      commonFileExt: 'Allgemeine Dateiendung',
      fileType: 'Dateityp',
      fileExt: 'Dateiendung',
      directoryPath: 'Verzeichnispfad',
      filePath: 'Dateipfad',
      semver: 'Semver',
      manufacturer: 'Hersteller',
      model: 'Modell',
      fuel: 'Treibstoff',
      vin: 'Wein'
   }
};
